#========================================================================================
# package      DE_EPAGES::ShopVote::API::Cartridge
# base         DE_EPAGES::Design::API::DesignInstaller
# state        public
#----------------------------------------------------------------------------------------
# description  This is the main cartridge class for install/patch/uninstall.
#========================================================================================
package DE_EPAGES::ShopVote::API::Cartridge;
use base DE_EPAGES::Design::API::DesignInstaller;

use strict;

#========================================================================================
# function     new
# state        private
#----------------------------------------------------------------------------------------
# syntax       $Installer = DE_EPAGES::ShopVote::API::Cartridge->new(%options);
#----------------------------------------------------------------------------------------
# description  Creates a new installer object of DE_EPAGES::ShopVote.
#----------------------------------------------------------------------------------------
# input        %options | options for un/install
#               <ul>
#                 <li>IsRecursive - recursive un/installation of required or dependent
#                     cartridges
#               </ul>
#               | hash
# return       $Installer | cartridge installer | object
#========================================================================================
sub new {
    my ($class, %options) = @_;

    my $self = __PACKAGE__->SUPER::new(
        %options,
        'CartridgeDirectory' => 'DE_EPAGES/ShopVote',
        'Version'            => '7.77.0',
        'Patches'            => ['7.68.0','7.69.0','7.70.0','7.71.0','7.72.0','7.73.0','7.74.0','7.75.0','7.76.0'],
    );
    return bless $self, $class;
}

#========================================================================================
# function     install
# state        private
#----------------------------------------------------------------------------------------
# syntax       $Installer->install;
#----------------------------------------------------------------------------------------
# description  Installs the cartridge.
#========================================================================================
sub install {
    my $self = shift;

    $self->startInstall;
    $self->SUPER::install;
    $self->finishInstall;
    return;
}

#========================================================================================
# function     uninstall
# state        private
#----------------------------------------------------------------------------------------
# syntax       $Installer->uninstall;
#----------------------------------------------------------------------------------------
# description  Uninstalls the cartridge.
#========================================================================================
sub uninstall {
    my $self = shift;

    $self->startUninstall;
    $self->SUPER::uninstall;
    $self->finishUninstall;
    return;
}

1;
